==> customized-facade-1.0.3-20190813.113834-27-sources.jar: com/bizvane/customized/facade/models/vo/GiftCardConsumeRequestVO.java <==
package com.bizvane.customized.facade.models.vo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

@Data
public class GiftCardConsumeRequestVO implements Serializable {

    private static final long serialVersionUID = 1L;
    /**
     * 卡号
     */
    private String cardNo;

    /**
     * 企业ID
     */
    private Long sysCompanyId;

    /**
     * 品牌ID
     */
    private Long sysBrandId;

    /**
     * 金额
     */
    private BigDecimal balance;

    /**
     * 单据编号
     */
    private String orderNo;

    /**
     * 操作人
     */
    private String userCode;

    /**
     * 状态
     */
    private String status;

    /**
     * 类型
     */
    private String type;

    /**
     * 操作时间
     */
    private String operateTime;

    /**
     * 有效期
     */
    private String validityTime;

    private String password;

    private BigDecimal updatebalance;

    private String consumer;

    private String createdDate;

    private String creater;

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getOperateTime() {
        return operateTime;
    }

    public void setOperateTime(String operateTime) {
        this.operateTime = operateTime;
    }

    public String getValidityTime() {
        return validityTime;
    }

    public void setValidityTime(String validityTime) {
        this.validityTime = validityTime;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public BigDecimal getUpdatebalance() {
        return updatebalance;
    }

    public void setUpdatebalance(BigDecimal updatebalance) {
        this.updatebalance = updatebalance;
    }

    public String getConsumer() {
        return consumer;
    }

    public void setConsumer(String consumer) {
        this.consumer = consumer;
    }

    public String getCreatedDate() {
        return createdDate;
    }

    public void setCreatedDate(String createdDate) {
        this.createdDate = createdDate;
    }

    public String getCreater() {
        return creater;
    }

    public void setCreater(String creater) {
        this.creater = creater;
    }
}

==> customized-facade-1.0.3-20191125.101047-44-sources.jar: com/bizvane/customized/facade/models/vo/GiftCardConsumeRequestVO.java <==
package com.bizvane.customized.facade.models.vo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

@Data
public class GiftCardConsumeRequestVO implements Serializable {

    private static final long serialVersionUID = 1L;
    /**
     * 卡号
     */
    private String cardNo;

    /**
     * 企业ID
     */
    private Long sysCompanyId;

    /**
     * 品牌ID
     */
    private Long sysBrandId;

    /**
     * 金额
     */
    private BigDecimal balance;

    /**
     * 单据编号
     */
    private String orderNo;

    /**
     * 操作人
     */
    private String userCode;

    /**
     * 状态
     */
    private String status;

    /**
     * 类型
     */
    private String type;

    /**
     * 操作时间
     */
    private String operateTime;

    /**
     * 有效期
     */
    private String validityTime;

    private String password;

    private BigDecimal updatebalance;

    private String consumer;

    private String createdDate;

    private String creater;

    //验证id
    private String verifyId;

    /**
     * 线下核销门店code
     */
    private String useStoreCode;

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getOperateTime() {
        return operateTime;
    }

    public void setOperateTime(String operateTime) {
        this.operateTime = operateTime;
    }

    public String getValidityTime() {
        return validityTime;
    }

    public void setValidityTime(String validityTime) {
        this.validityTime = validityTime;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public BigDecimal getUpdatebalance() {
        return updatebalance;
    }

    public void setUpdatebalance(BigDecimal updatebalance) {
        this.updatebalance = updatebalance;
    }

    public String getConsumer() {
        return consumer;
    }

    public void setConsumer(String consumer) {
        this.consumer = consumer;
    }

    public String getCreatedDate() {
        return createdDate;
    }

    public void setCreatedDate(String createdDate) {
        this.createdDate = createdDate;
    }

    public String getCreater() {
        return creater;
    }

    public void setCreater(String creater) {
        this.creater = creater;
    }

    public String getUseStoreCode() {
        return useStoreCode;
    }

    public void setUseStoreCode(String useStoreCode) {
        this.useStoreCode = useStoreCode;
    }
}
